@@ -8,7 +8,7 @@
   unlockBinding(".distrTEstoptions", asNamespace("distrTEst"))
 buildStartupMessage(pkg="distrTEst", packageHelp=TRUE, library=library, 
 # MANUAL="http://www.uni-bayreuth.de/departments/math/org/mathe7/DISTR/distr.pdf",
-VIGNETTE = gettext("Package \"distrDoc\" provides a vignette to this package as well as\nto several related packages; try vignette(\"distr\")."))
+VIGNETTE = gettext("Package \"distrDoc\" provides a vignette to this package as well as to several related packages; try vignette(\"distr\")."))
 ###
   invisible()
 }
